"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

const util_1 = require("../../util");

const getLocaleSpecies_1 = require("../locale/getLocaleSpecies");

async function getLocaleOptions(api) {
  var _api$userConfig$local;

  const localeSpecies = await getLocaleSpecies_1.getLocaleSpecies(api, {
    defaultValue: [{
      originName: 'zh-CN',
      underlineName: 'zhCN'
    }]
  });
  const locales = [];
  const imports = [];
  localeSpecies.forEach(({
    originName,
    underlineName
  }) => {
    const horizontalLineToUnderscoreName = originName.replace(/-|_|\./g, '_');
    locales.push(`'${originName}': ${underlineName}`);
    imports.push(util_1.spliceImportFrom(underlineName, `antd/es/locale/${horizontalLineToUnderscoreName}`));
  });
  const importsText = imports.join('\n');
  const localesText = `
const locales = {
  ${locales.join(',\n  ')}
} as const;
`;
  return {
    importsText,
    localesText,
    isI18n: Boolean(api.userConfig.locale),
    defaultLocale: ((_api$userConfig$local = api.userConfig.locale) === null || _api$userConfig$local === void 0 ? void 0 : _api$userConfig$local.default) || localeSpecies[0].originName
  };
}

async function antd(api) {
  api.describe({
    enable: () => !!api.userConfig.antd,
    onReCompile: enable => {
      if (!enable) {
        api.generateFile.removeTmpFile('antd');
      }
    }
  });
  api.onGenerateFiles({
    stage: 9,
    fn: async () => {
      var _api$userConfig$antd;

      api.generateFile.writeFile({
        path: 'antd/index.tsx',
        content: api.generateFile.renderTpl(api.generateFile.readTplFile(__dirname, 'RenderAntdConfigProviderComponent.tpl'), { ...(await getLocaleOptions(api)),
          ...(((_api$userConfig$antd = api.userConfig.antd) === null || _api$userConfig$antd === void 0 ? void 0 : _api$userConfig$antd.config) || {})
        })
      });
    }
  });
  api.addImportToAppEntryFile(() => ({
    specifier: '{ RenderAntdConfigProvider }',
    source: api.resolveConfigAliasNamePath('antd')
  }));
  api.addContainerRenderToAppEntryFile({
    stage: 997,
    fn: () => `
function renderAntdConfigProvider(children?: React.ReactElement) {
  return <RenderAntdConfigProvider>{children}</RenderAntdConfigProvider>;
}`
  });
}

exports.default = antd;